UnityPanelWidget,
.unity-panel {
    border-width: 0 0 1px 0;
    border-style: solid;
    border-color: @panel_bg_color;
    background-color: @panel_bg_color;
    background-image: none;
    color: @panel_fg_color;
}

.unity-panel.menubar,
.unity-panel .menubar {
}

.unity-panel.menuitem,
.unity-panel .menuitem {
    border-width: 0 1px;
    color: @panel_fg_color;
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
    border-color: mix(@panel_bg_color, @panel_fg_color, 0.21);
    background-color: mix(@panel_bg_color, @panel_fg_color, 0.21);
    background-image: none;
    color: shade(@panel_fg_color, 1.08);
}
