/***********************
 * fallback mode panel *
 ***********************/
PanelWidget,
PanelApplet,
PanelToplevel {
    padding: 0;
    background-color: @panel_bg_color;
    background-image: none;
    color: @panel_fg_color;
}

PanelApplet {
    border-width: 0;
}

PanelSeparator {
    border-width: 0;
    background-color: @panel_bg_color;
    background-image: none;
    color: @panel_fg_color;
}

.gnome-panel-menu-bar,
PanelApplet > GtkMenuBar.menubar,
PanelApplet > GtkMenuBar.menubar.menuitem,
PanelMenuBar.menubar,
PanelMenuBar.menubar.menuitem {
    -Panelpanel-icon-visible: true;

    border-width: 0;
    background-color: @panel_bg_color;
    background-image: none;
}

PanelAppletFrame {
    border-width: 0;
    background-color: @panel_bg_color;
    background-image: none;
}

PanelApplet .button {
    -GtkButton-inner-border: 2;

    border-width: 0 1px;
    border-radius: 0;
    border-color: transparent;
    background-color: @panel_bg_color;
    background-image: none;
    color: @panel_fg_color;
}

PanelApplet .button:active {
    border-width: 0 1px;
    border-radius: 0;
    border-color: mix(@panel_bg_color, @panel_fg_color, 0.21);
    background-color: mix(@panel_bg_color, @panel_fg_color, 0.21);
    background-image: none;
    color: shade(@panel_fg_color, 1.08);
}

PanelApplet .button:prelight {
    border-color: mix(@panel_bg_color, @panel_fg_color, 0.11);
    background-color: mix(@panel_bg_color, @panel_fg_color, 0.11);
    background-image: none;
    color: shade(@panel_fg_color, 1.08);
}

PanelApplet .button:active:prelight {
    border-color: mix(@panel_bg_color, @panel_fg_color, 0.31);
    background-color: mix(@panel_bg_color, @panel_fg_color, 0.31);
    background-image: none;
    color: shade(@panel_fg_color, 1.08);
}

WnckPager, WnckTasklist {
    background-color: @panel_bg_color;
}

/************
 * nautilus *
 ************/
.nautilus-canvas-item {
    border-radius: 2px;
}

.nautilus-desktop.nautilus-canvas-item {
    color: white;
    text-shadow: 1px 1px black;
}

.nautilus-desktop.nautilus-canvas-item:active {
    color: @theme_fg_color;
}

.nautilus-desktop.nautilus-canvas-item:selected {
    color: @theme_selected_fg_color;
}

.nautilus-desktop.nautilus-canvas-item:active,
.nautilus-desktop.nautilus-canvas-item:prelight,
.nautilus-desktop.nautilus-canvas-item:selected {
    text-shadow: none;
}

NautilusWindow .toolbar {
    border-width: 0 0 1px;
    border-style: solid;
    border-color: shade(@toolbar_bg_color, 0.8);
}

NautilusWindow .sidebar .frame {
    border-style: none;
}

NautilusWindow > GtkGrid > .pane-separator,
NautilusWindow > GtkGrid > .pane-separator:hover {
    border-width: 0 1px 0 0;
    border-style: solid;
    border-color: shade(@theme_bg_color, 0.8);
    background-color: @theme_bg_color;
}

NautilusNotebook.notebook {
    border-right-width: 0;
    border-left-width: 0;
    border-bottom-width: 0;
}

NautilusNotebook .frame {
    border-width: 0;
}

NautilusQueryEditor .primary-toolbar.toolbar {
    border-top-width: 0;
    border-bottom-width: 0;
}

NautilusQueryEditor .toolbar {
    padding-top: 3px;
    padding-bottom: 2px;
    border-width: 1px 0 0 0;
    border-style: solid;
    border-color: @toolbar_bg_color;
    background-color: shade(@toolbar_bg_color, 0.9);
}

NautilusQueryEditor .toolbar:nth-child(2) {
    border-color: shade(@toolbar_bg_color, 0.8);
}

NautilusQueryEditor .toolbar:last-child,
NautilusQueryEditor .primary-toolbar.toolbar:only-child {
    border-bottom-width: 1px;
    border-bottom-color: shade(@toolbar_bg_color, 0.8);
}

/******************
 * gnome terminal *
 ******************/
VteTerminal {
    background-color: @osd_base;
    color: @osd_fg;
}

TerminalWindow GtkNotebook.notebook {
    border-right-width: 0;
    border-bottom-width: 0;
    border-left-width: 0;
}

TerminalWindow .scrollbars-junction,
TerminalWindow .scrollbar.trough {
    background-color: @osd_base;
}

TerminalWindow .scrollbar.button,
TerminalWindow .scrollbar.button:active,
TerminalWindow .scrollbar.button:active:hover {
    color: shade(@osd_base, 0.6);
}

TerminalWindow .scrollbar.slider {
    border-color: mix(shade(@osd_base, 0.87), @osd_fg, 0.21);
    background-color: mix(@osd_base, @osd_fg, 0.21);
}

TerminalWindow .scrollbar.slider:hover,
TerminalWindow .scrollbar.slider.vertical:hover {
    border-color: mix(shade(@osd_base, 0.87), @osd_fg, 0.31);
    background-color: mix(@osd_base, @osd_fg, 0.31);
}

TerminalWindow .scrollbar.slider:active,
TerminalWindow .scrollbar.slider.vertical:active {
    border-color: shade(@theme_selected_bg_color, 0.9);
    background-color: @theme_selected_bg_color;
}

/*********
 * gedit *
 *********/
GeditWindow .pane-separator, 
GeditWindow .pane-separator:hover {
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-color: shade(@theme_bg_color, 0.8);
    background-color: @theme_bg_color;
    color: shade(@theme_bg_color, 0.8);
}

GeditPanel.title GtkLabel {
    padding: 4px 0;
}

GeditPanel.vertical .title {
    padding: 4px 0 4px 3px;
    border-style: none;
}

GeditPanel .toolbar {
    border-style: none;
    background-color: transparent;
}

GeditDocumentsPanel .view {
    background-color: @theme_base_color;
}

GeditPanel.vertical .notebook {
    padding: 0;
    border-width: 1px 0;
}

GeditPanel.horizontal .notebook {
    padding: 0;
    border-width: 0 1px 1px 0;
}

GeditWindow .notebook {
    border-width: 1px 0;
}

GeditPanel .notebook tab,
GeditWindow .notebook tab {
    border-width: 0;
}

GeditStatusComboBox .button,
GeditStatusComboBox .button:hover,
GeditStatusComboBox .button:active,
GeditStatusComboBox .button:active:hover {
    padding: 1px 6px 2px 4px;
    border-style: solid;
    border-width: 0 1px;
    border-radius: 0;
}

GeditStatusComboBox .button:hover,
GeditStatusComboBox .button:active,
GeditStatusComboBox .button:active:hover {
    border-color: shade(@theme_bg_color, 0.8);
}

GeditViewFrame .gedit-search-slider {
    padding: 4px;
    border-radius: 0 0 2px 2px;
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-color: shade(@theme_base_color, 0.8);
    background-color: @theme_base_color;
}

GeditViewFrame .gedit-search-slider .not-found {
    background-color: @error_bg_color;
    background-image: none;
    color: @error_fg_color;
}

GeditViewFrame .gedit-search-slider .not-found:selected {
    background-color: @theme_selected_bg_color;
    color: @theme_selected_fg_color;
}

GeditFileBrowserWidget .primary-toolbar.toolbar  {
    padding: 2px;
    border-top: none;
    background-color: @theme_bg_color;
    background-image: none;
}

/***************
 * font-viewer *
 ***************/
SushiFontWidget {
    padding: 6px 12px;
}

/*************
 * gucharmap *
 *************/
GucharmapChartable {
    background-color: @theme_base_color;
}

GucharmapChartable:active,
GucharmapChartable:focus,
GucharmapChartable:selected {
    background-color: @theme_selected_bg_color;
    color: @theme_selected_fg_color;
}
